
Publications
############

References to peer-reviewed publications, theses and reports describing in
detail and applying the methods implemented in the ``pyunicorn`` package.

General complex networks
========================
- Review papers: [Newman2003]_, [Boccaletti2006]_, [Costa2007]_.
- Further network papers: [Watts1998]_, [Newman2001]_, [Newman2002]_,
  [Arenas2003]_, [Newman2005]_, [Soffer2005]_, [Holme2007]_, [Tsonis2008a]_,
  [Ueoka2008]_.

....

.. [Newman2003] M.E.J. Newman.
    "The structure and function of complex networks".
    In *SIAM Review*, vol. 45 (no. 2), p167-256 (2003)
    `doi:10.1137/S003614450342480
    <http://dx.doi.org/10.1137/S003614450342480>`__

.. [Boccaletti2006] S. Boccaletti, V. Latora, Y. Moreno, M. Chavez, D.U. Hwang.
    "Complex networks: structure and dynamics".
    In *Physics Reports*, vol. 424 (no. 4-5), p175-308 (2006)
    `doi:10.1016/j.physrep.2005.10.009
    <http://dx.doi.org/10.1016/j.physrep.2005.10.009>`__

.. [Costa2007] L.D.F. Costa, F.A. Rodrigues, G. Travieso, P.R. Villas Boas.
    "Characterization of complex networks: A survey of measurements".
    In *Advances in Physics*, vol. 56(1), 167-242 (2007)
    `doi:10.1080/00018730601170527
    <http://dx.doi.org/10.1080/00018730601170527>`__

.. [Watts1998] D.J. Watts and S.H. Strogatz.
    "Collective dynamics of small-world networks".
    In *Nature* vol. 393, 440–442 (1998)
    `doi:10.1038/30918 <http://dx.doi.org/10.1038/30918>`__

.. [Newman2001] M.E.J. Newman.
    "Scientific collaboration networks. II. Shortest paths, weighted
    networks, and centrality".
    In *Physical Review E* vol. 64.1, 016132 (2001)
    `doi:10.1103/PhysRevE.64.016132
    <http://dx.doi.org/10.1103/PhysRevE.64.016132>`__

.. [Newman2002] M.E.J. Newman.
    "Assortative mixing in networks".
    In *Physical Review Letters*, vol. 89.20, 208701 (2002)
    `doi:10.1103/PhysRevLett.112.068103
    <http://dx.doi.org/10.1103/PhysRevLett.112.068103>`__

.. [Arenas2003]  A. Arenas, A. Cabrales, A. Díaz-Guilera, R. Guimerà, F. Vega-Redondo.
    "Search and Congestion in Complex Networks".
    In "Statistical Mechanics of Complex Networks",
    In *Lecture Notes in Physics*, vol. 625, p175-194 (2003)
    `doi:10.1007/978-3-540-44943-0_11
    <http://dx.doi.org/10.1007/978-3-540-44943-0_11>`__

.. [Newman2005] M.E.J. Newman.
    "A measure of betweenness centrality based on random walks".
    In *Social Networks*, vol 27 (no. 1), p39–54 (2005)
    `doi:10.1016/j.socnet.2004.11.009
    <http://dx.doi.org/10.1016/j.socnet.2004.11.009>`__

.. [Soffer2005] S.N. Soffer and A. Vázquez
    "Network clustering coefficient without degree-correlation biases".
    In *Physical Review E*, vol. 71, 057101 (2005)
    `doi:10.1103/PhysRevE.71.057101
    <http://dx.doi.org/10.1103/PhysRevE.71.057101>`__

.. [Holme2007] P. Holme, S.M. Park, B.J. Kim, C.R. Edling.
    "Korean university life in a network perspective: Dynamics of a large
    affiliation network".
    In *Physica A: Statistical Mechanics and its Applications*,
    vol. 373, p821-830 (2007)
    `doi:10.1016/j.physa.2006.04.066
    <http://dx.doi.org/10.1016/j.physa.2006.04.066>`__

.. [Tsonis2008a] A.A. Tsonis, K.L. Swanson, G. Wang.
    "Estimating the clustering coefficient in scale-free networks on lattices
    with local spatial correlation structure".
    In *Physica A: Statistical Mechanics and its Applications*,
    vol. 387 (no. 21) p5287-5294 (2008)
    `doi:10.1016/j.physa.2008.05.048
    <http://dx.doi.org/10.1016/j.physa.2008.05.048>`__

.. [Ueoka2008] Y. Ueoka, T. Suzuki, T. Ikeguchi, Y. Horio.
    "Efficiency of Statistical Measures to Estimate Network Structure of Chaos
    Coupled Systems".
    Proceedings of NOLTA (2008)
    http://tsuzuki.ise.ibaraki.ac.jp/MyPaper/Meeting/08NOLTA.pdf


Spatially embedded networks
===========================
- [Bartelemy2011]_.

....

.. [Bartelemy2011] M. Barthelemy.
    "Spatial networks".
    In *Physics Reports*, vol. 499 (no. 1-3), p1-101 (2011)
    `doi:10.1016/j.physrep.2010.11.002
    <http://dx.doi.org/10.1016/j.physrep.2010.11.002>`__


Interacting/interdependent networks (networks of networks)
==========================================================
- Introduction to structural analysis of interacting networks: [Donges2011a]_.
- Random graph models & network surrogates for interacting networks: [Schultz2010]_.

....

.. [Donges2011a] J.F. Donges, H.C.H. Schultz, N. Marwan, Y. Zou, J. Kurths.
    "Investigating the topology of interacting networks - Theory and
    application to coupled climate subnetworks".
    In *European Physical Journal B: Condensed Matter and Complex Systems*,
    vol. 84 (no. 4) p635-652 (2011)
    `doi:10.1140/epjb/e2011-10795-8
    <http://dx.doi.org/10.1140/epjb/e2011-10795-8>`__

.. [Schultz2010] H.C.H. Schultz.
    "Coupled climate networks: Investigating the terrestrial atmosphere's
    dynamical structure".
    Diploma thesis, Free University, Berlin (2010)


Node-weighted (node-splitting invariant) network measures
=========================================================
- Introduction: [Heitzig2012]_.
- Analysis of node-weighted interacting networks: [Wiedermann2011]_, [Wiedermann2013]_.

....

.. [Heitzig2012] J. Heitzig, J. F. Donges, Y. Zou, N. Marwan, J. Kurths.
    "Node-weighted measures for complex networks with spatially embedded,
    sampled, or differently sized nodes".
    In *European Physical Journal B: Condensed Matter and Complex Systems*,
    vol. 85 p38 (2012)
    `doi:10.1140/epjb/e2011-20678-7
    <http://dx.doi.org/10.1140/epjb/e2011-20678-7>`__

.. [Wiedermann2011] M. Wiedermann.
    "Coupled climate network analysis of multidecadal dynamics in the Arctic".
    Bachelor's thesis, Humboldt University, Berlin (2011)

.. [Wiedermann2013] M. Wiedermann, J.F. Donges, J. Heitzig, J. Kurths.
    "Node-weighted interacting network measures improve the representation
    of real-world complex systems".
    In *Europhysics Letters*, vol. 102.2, 28007 (2013)
    `doi:10.1209/0295-5075/102/28007
    <http://dx.doi.org/10.1209/0295-5075/102/28007>`__

.. [Zemp2014] D.C. Zemp,  M. Wiedermann, J. Kurths, A. Rammig, J.F. Donges.
    "Node-weighted measures for complex networks with directed and weighted
    edges for studying continental moisture recycling".
    In *Europhysics Letters*, vol. 107.5, p58005 (2014)
    `doi:10.1209/0295-5075/107/58005
    <http://dx.doi.org/10.1209/0295-5075/107/58005>`__


Climate data analysis (general)
===============================
- [Bretherton1992]_.

....

.. [Bretherton1992] C.S. Bretherton, C. Smith, J.M. Wallace.
    "An intercomparison of methods for finding coupled patterns in climate
    data".
    In *Journal of Climate*, vol. 5, p541-560 (1992)
    `doi:10.1175/1520-0442(1992)005<0541:AIOMFF>2.0.CO;2
    <http://dx.doi.org/10.1175/1520-0442(1992)005%3C0541%3AAIOMFF%3E2.0.CO%3B2>`__


(Coupled) Climate networks
==========================
- Comparing linear & nonlinear construction of climate networks: [Donges2009a]_.
- Studying the dynamical structure of the surface air temperature field:
  [Donges2009b]_, [Radebach2010]_.
- Introduction to coupled climate networks & applications:
  [Schultz2010]_, [Donges2011a]_, [Wiedermann2011]_.
- Review of climate network analysis (in Chinese!): [Zou2011]_.
- Visualization of climate networks: [Tominski2011]_.
- Evolving climate networks: [Radebach2013]_.
- General: [Tsonis2004]_, [Tsonis2006]_, [Gozolchiani2008]_, [Tsonis2008b]_,
  [Tsonis2008c]_, [Yamasaki2008]_, [Donges2009c]_, [Yamasaki2009]_.

....

.. [Donges2009a] J.F. Donges, Y. Zou, N. Marwan, J. Kurths.
    "Complex networks in climate dynamics".
    In *European Physical Journal Special Topics*, vol. 174 (no. 1), p157-179
    (2009)
    `doi:10.1140/epjst/e2009-01098-2
    <http://dx.doi.org/10.1140/epjst/e2009-01098-2>`__

.. [Donges2009b] J.F. Donges, Y. Zou, N. Marwan, J. Kurths.
    "The backbone of the climate network".
    In *Europhysics Letters*, vol. 87 (no. 4), 48007 (2009)
    `doi:10.1209/0295-5075/87/48007
    <http://dx.doi.org/10.1209/0295-5075/87/48007>`__

.. [Radebach2010] A. Radebach.
    "Evolving climate networks: Investigating the evolution of correlation
    structure of the Earth's climate system".
    Diploma thesis, Humboldt University, Berlin (2010)

.. [Zou2011] Y. Zou, J.F. Donges, J. Kurths.
    "Recent advances in complex climate network analysis".
    In *Complex Systems and Complexity Science*, vol. 8 (no. 1), p27-38 (2011)

.. [Tominski2011] C. Tominski, J.F. Donges, T. Nocke.
    "Information Visualization in Climate Research".
    In *Proceedings of the International Conference on Information
    Visualisation (IV), London*, p298-305 (2011)
    `doi:10.1109/IV.2011.12 <http://dx.doi.org/10.1109/IV.2011.12>`__

.. [Radebach2013] A. Radebach, R.V. Donner, J. Runge, J.F. Donges, J. Kurths.
    "Disentangling different types of El Nino episodes by evolving climate
    network analysis".
    In *Physical Review E*, vol. 88, 052807 (2013)
    `doi:10.1103/PhysRevE.88.052807
    <http://dx.doi.org/10.1103/PhysRevE.88.052807>`__

.. [Tsonis2004] A.A. Tsonis and P.J. Roebber.
    "The architecture of the climate network".
    In *Physica A: Statistical Mechanics and its Applications*,
    vol. 333, p497-504 (2004)
    `doi:10.1016/j.physa.2003.10.045
    <http://dx.doi.org/10.1016/j.physa.2003.10.045>`__

.. [Tsonis2006] A.A. Tsonis, K.L. Swanson, P.J. Roebber.
    "What do networks have to do with climate?".
    In *Bull. Amer. Meteor. Soc.* vol. 87 p585-595 (2006)
    `doi:10.1175/BAMS-87-5-585 <http://dx.doi.org/10.1175/BAMS-87-5-585>`__

.. [Gozolchiani2008] A. Gozolchiani, K. Yamasaki, O. Gazit, S. Havlin.
    "Pattern of climate network blinking links follows El Niño events".
    In *Europhysics Letters*, vol. 83 (no. 2), 28005 (2008)
    `doi:10.1209/0295-5075/83/28005
    <http://dx.doi.org/10.1209/0295-5075/83/28005>`__

.. [Tsonis2008b] A. A. Tsonis and K. L. Swanson.
    "Topology and Predictability of El Niño and La Niña Networks".
    In *Physical Review Letters* vol 100, 228502 (2008)
    `doi:10.1103/PhysRevLett.100.228502
    <http://dx.doi.org/10.1103/PhysRevLett.100.228502>`__

.. [Tsonis2008c] A. A. Tsonis, K. L. Swanson, G. Wang.
    "On the role of atmospheric teleconnections in climate".
    In *Journal of Climate* vol. 21, p2990-3001 (2008)
    `doi:10.1175/2007JCLI1907.1 <http://dx.doi.org/10.1175/2007JCLI1907.1>`__

.. [Yamasaki2008] K. Yamasaki, A. Gozolchiani, S. Havlin.
    "Climate Networks around the Globe are Significantly Affected by El Niño".
    In *Physical Review Letters*, vol. 100, 228501 (2008)
    `doi:10.1103/PhysRevLett.100.228501
    <http://dx.doi.org/10.1103/PhysRevLett.100.228501>`__

.. [Donges2009c] J.F. Donges
    "Complex networks in the climate system".
    Diploma thesis, University of Potsdam (2009)
    Advisor: Prof. Dr. Dr. h.c. Juergen Kurths.
    URN: ``urn:nbn:de:kobv:517-opus-49775``.

.. [Yamasaki2009] K. Yamasaki, A. Gozolchiani, S. Havlin.
    "Climate Networks Based on Phase Synchronization Analysis Track El-Niño".
    In *Progress Of Theoretical Physics Supplement*, vol. 179, p178-188 (2009)
    `doi:10.1143/PTPS.179.178 <http://dx.doi.org/10.1143/PTPS.179.178>`__


Power grids & Power networks
============================
- Resistance based networks: [Schultz2014]_, [Schultz2014a]_.

....

.. [Schultz2014] P. Schultz "Stability Analysis of Power Grid Networks".
    *M.Sc. Thesis*, Humboldt-Universität zu Berlin (2014)

.. [Schultz2014a] P. Schultz, J. Heitzig, J. Kurths
    A Random Growth Model for Power Grids and Other
    Spatially Embedded Infrastructure Networks".
    In *Eur. Phys. J. Special Topics: Resilient Power Grids and Extreme Events* (2014)


Time series analysis & Synchronization
======================================
- General: [Pecora1998]_, [Schreiber2000]_, [Bandt2002]_, [Kraskov2004]_,
  [Kantz2006]_, [Thiel2006]_, [Bergner2008]_, [Pompe2011]_, [Ribeiro2011]_, [Runge2012b]_.
- Event synchronization: [Quiroga2002]_, [Boers2014]_.
- Event coincidence analysis: [Odenweller2020]_.

....

.. [Pecora1998] L.M. Pecora and T.L. Carroll.
    "Master Stability Functions for Synchronized Coupled Systems".
    In *Physical Review Letters*, vol. 80, 2109 (1998)
    `doi:10.1103/PhysRevLett.80.2109
    <http://dx.doi.org/10.1103/PhysRevLett.80.2109>`__

.. [Schreiber2000] T. Schreiber and A. Schmitz.
    "Surrogate time series".
    In *Physica D* vol. 142 (no. 3-4), p346-382 (2000)
    `doi:10.1016/S0167-2789(00)00043-9
    <http://dx.doi.org/10.1016/S0167-2789(00)00043-9>`__

.. [Bandt2002] C. Bandt, B. Pompe
    "Permutation Entropy: A Natural Complexity Measure for Time Series".
    In *Phys. Rev. Lett.*, vol. 88(17), 174102 (2002)
    `doi:10.1103/PhysRevLett.88.174102
    <http://dx.doi.org/10.1103/PhysRevLett.88.174102>`__

.. [Kraskov2004] A. Kraskov, H. Stögbauer, P. Grassberger.
    "Estimating mutual information".
    In *Physical Review E*, vol. 69(6), 066138 (2004)
    `doi:10.1103/PhysRevE.69.066138
    <http://dx.doi.org/10.1103/PhysRevE.69.066138>`__

.. [Kantz2006] H. Kantz and T. Schreiber.
    "Nonlinear Time Series Analysis".
    Cambridge University Press, Cambridge, 2nd edition (2006)

.. [Thiel2006] M. Thiel, M.C. Romano, J. Kurths, M. Rolfs, R. Kliegl.
    "Twin surrogates to test for complex synchronization".
    In *Europhysics Letters*, vol. 75, p535-541 (2006)
    `doi:10.1209/epl/i2006-10147-0
    <http://dx.doi.org/10.1209/epl/i2006-10147-0>`__

.. [Bergner2008] A. Bergner, R. Meucci, K. Al Naimee, M.C. Romano, M. Thiel,
    J. Kurths, and F. T. Arecchi.
    "Continuous wavelet transform in the analysis of burst synchronization in a
    coupled laser system".
    In *Physical Review E*, vol. 78, 016211 (2008)
    `doi:10.1103/PhysRevE.78.016211
    <http://dx.doi.org/10.1103/PhysRevE.78.016211>`__

.. [Pompe2011] B. Pompe, J. Runge.
    "Momentary information transfer as a coupling measure of time series".
    In *Physical Review E* vol. 83, 051122 (2011)
    `doi:10.1103/PhysRevE.83.051122
    <http://dx.doi.org/10.1103/PhysRevE.83.051122>`__

.. [Ribeiro2011] H.V. Ribeiro, L. Zunino, R.S. Mendes and E.K. Lenzi
    "Complexity–entropy causality plane: A useful approach for
    distinguishing songs",
    In *Physica A: Statistical Mechanics and its Applications*,
    vol. 391, p2421-2428 (2011)
    `doi:10.1016/j.physa.2011.12.009
    <http://dx.doi.org/10.1016/j.physa.2011.12.009>`__

.. [Runge2012b] J. Runge, J. Heitzig, N. Marwan, J. Kurths.
    "Quantifying causal coupling strength: A lag-specific measure for
    multivariate time series related to transfer entropy".
    In *Physical Review E*, vol. 86(6), 1-15 (2012)
    `doi:10.1103/PhysRevE.86.061121
    <http://dx.doi.org/10.1103/PhysRevE.86.061121>`__

.. [Quiroga2002] R.Q. Quiroga, T. Kreuz, P. Grassberger.
    "Event synchronization: a simple and fast method to measure synchronicity
    and time delay patterns."
    In *Physical Review E*, vol. 66(4), 041904 (2002)
    `doi:10.1103/PhysRevE.66.041904
    <http://dx.doi.org/10.1103/PhysRevE.66.041904>`__

.. [Boers2014] N. Boers, B. Bookhagen, H.M.J. Barbosa, N. Marwan, J. Kurths.
    J.A. Marengo.
    "Prediction of extreme floods in the eastern Central Andes based on a
    complex networks approach".
    In *Nature communications*, vol. 5, 1--7 (2014)
    `doi:10.1038/ncomms6199
    <http://dx.doi.org/10.1038/ncomms6199>`__

.. [Odenweller2020] A. Odenweller, R.V. Donner.
    "Disentangling synchrony from serial dependency in paired-event time series".
    In *Pyhsical Review E*, vol. 101, 052213 (2020)
    `doi:10.1103/PhysRevE.101.052213
    <https://doi.org/10.1103/PhysRevE.101.052213>`__


Recurrence quantification/network analysis
==========================================
- Review of recurrence plots & RQA: [Marwan2007]_.
- Introduction & application of recurrence networks in the context of RQA: [Marwan2009]_.
- Thorough introduction to recurrence network analysis: [Donner2010b]_.
- Discussion of choosing an appropriate recurrence threshold: [Donner2010a]_, [Zou2010]_.
- Review of various methods for network-based time series analysis: [Donner2011a]_.
- Introduction to measures of (fractal) transitivity dimensions: [Donner2011b]_.
- Applications of recurrence network analysis to paleoclimate data: [Donges2011b]_,
  [Donges2011c]_, [Feldhoff2012]_.
- Theory of recurrence networks: [Donges2012]_, [Zou2012]_.
- Multivariate extensions of recurrence network analysis: [Feldhoff2012]_, [Feldhoff2013]_.
- General: [Ngamga2007]_, [Xu2008]_, [Schinkel2009]_.

....

.. [Marwan2007] N. Marwan, M.C. Romano, M. Thiel, J. Kurths.
    "Recurrence plots for the analysis of complex systems".
    In *Physics Reports*, vol. 438 (no. 5–6), p237-329 (2007)
    `doi:10.1016/j.physrep.2006.11.001
    <http://dx.doi.org/10.1016/j.physrep.2006.11.001>`__

.. [Marwan2009] N. Marwan, J.F. Donges, Y. Zou, R.V. Donner, J. Kurths.
    "Complex network approach for recurrence analysis of time series".
    In *Physics Letters A*, vol. 373 (no. 46), p4246-4254 (2009)
    `doi:10.1016/j.physleta.2009.09.042
    <http://dx.doi.org/10.1016/j.physleta.2009.09.042>`__

.. [Donner2010b] R.V. Donner, Y. Zou, J.F. Donges, N. Marwan, J. Kurths.
    "Recurrence networks -- A novel paradigm for nonlinear time series
    analysis".
    In *New Journal of Physics*, vol. 12 (no. 3), 033205 (2010)
    `doi:10.1088/1367-2630/12/3/033025
    <http://dx.doi.org/10.1088/1367-2630/12/3/033025>`__

.. [Donner2010a] R.V. Donner, Y. Zou, J.F. Donges, N. Marwan, J. Kurths.
    "Ambiguities in recurrence-based complex network representations of time
    series".
    In *Physical Review E*,
    vol. 81 (no. 1), 015101(R) (2010)
    `doi:10.1103/PhysRevE.81.015101
    <http://dx.doi.org/10.1103/PhysRevE.81.015101>`__

.. [Zou2010] Y. Zou, R.V. Donner, J.F. Donges, N. Marwan, J. Kurths.
    "Identifying complex periodic windows in continuous-time dynamical systems
    using recurrence-based methods".
    In *Chaos*, vol. 20 (no. 4), 043130 (2010)
    `doi:10.1063/1.3523304 <http://dx.doi.org/10.1063/1.3523304>`__

.. [Donner2011a] R.V. Donner, M. Small, J.F. Donges, N. Marwan, Y. Zou, R.
    Xiang, J. Kurths.
    "Recurrence-based time series analysis by means of complex network
    methods".
    In *International Journal of Bifurcation and Chaos*, vol. 21 (no. 4),
    p1019-1046 (2011)
    `doi:10.1142/S0218127411029021
    <http://dx.doi.org/10.1142/S0218127411029021>`__

.. [Donner2011b] R.V. Donner, J. Heitzig, J.F. Donges, Y. Zou, J. Kurths.
    "The geometry of chaotic dynamics -- A complex network perspective".
    In *European Physical Journal B: Condensed Matter and Complex Systems*,
    vol. 84 (no. 4), p653-672 (2011)
    `doi:10.1140/epjb/e2011-10899-1
    <http://dx.doi.org/10.1140/epjb/e2011-10899-1>`__

.. [Donges2011b] J.F. Donges, R.V. Donner, K. Rehfeld, N. Marwan, M.H.
    Trauth, J. Kurths.
    "Identification of dynamical transitions in marine palaeoclimate records
    by recurrence network analysis".
    In *Nonlinear Processes in Geophysics*, vol. 18 (no. 5), p545-562 (2011)
    `doi:10.5194/npg-18-545-2011
    <http://dx.doi.org/10.5194/npg-18-545-2011>`__

.. [Donges2011c] J.F. Donges, R.V. Donner, M.H. Trauth, N. Marwan, H.J.
    Schellnhuber, J. Kurths.
    "Nonlinear detection of paleoclimate-variability transitions possibly
    related to human evolution".
    In *Proceedings of the National Academy of Sciences of the United States of
    America*, vol. 108 (no. 51), p20422-20427 (2011)
    `doi:10.1073/pnas.1117052108
    <http://dx.doi.org/10.1073/pnas.1117052108>`__

.. [Donges2012] J.F. Donges, J. Heitzig, R.V. Donner, J. Kurths.
    "Analytical framework for recurrence network analysis of time series".
    In *Physical Review E: Statistical, Nonlinear, and Soft Matter Physics*,
    vol. 85, 046105 (2012)
    `doi:10.1103/PhysRevE.85.046105
    <http://dx.doi.org/10.1103/PhysRevE.85.046105>`__

.. [Zou2012] Y. Zou, J. Heitzig, R.V. Donner, J.F. Donges, J.D. Farmer, R.
    Meucci, S. Euzzor, N. Marwan, J. Kurths.
    "Power-laws in recurrence networks from dynamical systems".
    In *Europhysics Letters*, vol. 98, 48001 (2012)
    `doi:10.1209/0295-5075/98/48001
    <http://dx.doi.org/10.1209/0295-5075/98/48001>`__

.. [Feldhoff2012] J.H. Feldhoff, R.V. Donner, J.F. Donges, N. Marwan,
    J. Kurths.
    "Geometric detection of coupling directions by means of inter-system
    recurrence networks".
    In *Physics Letters A*, vol. 376, 3504-3513 (2012),
    `doi:10.1016/j.physleta.2012.10.008
    <http://dx.doi.org/10.1016/j.physleta.2012.10.008>`__

.. [Feldhoff2013] J.H. Feldhoff, R.V. Donner, J.F. Donges, N. Marwan,
    J. Kurths.
    "Geometric signature of complex synchronisation scenarios".
    In *Europhysics Letters* vol. 102, 30007 (2013),
    `doi:10.1209/0295-5075/102/30007
    <http://dx.doi.org/10.1209/0295-5075/102/30007>`__

.. [Ngamga2007] E.J. Ngamga, A. Nandi, R. Ramaswamy, M.C. Romano, M. Thiel, J. Kurths.
    "Recurrence analysis of strange nonchaotic dynamics".
    In *Physical Review E*, vol. 75, 036222 (2007)
    `doi:10.1103/PhysRevE.75.036222
    <http://dx.doi.org/10.1103/PhysRevE.75.036222>`__

.. [Xu2008] X. Xu, J. Zhang, M. Small.
    "Superfamily phenomena and motifs of networks induced from time series".
    In *Proceedings of the National Academy of Sciences of the United States of
    America*, vol. 105 (no. 50) p19601-19605 (2008)
    `doi:10.1073/pnas.0806082105
    <http://dx.doi.org/10.1073/pnas.0806082105>`__

.. [Schinkel2009] S. Schinkel, N. Marwan, O. Dimigen, J. Kurths.
    "Confidence bounds of recurrence-based complexity measures".
    In *Physics Letters A*, vol. 373 (no. 26) p2245–2250 (2009)
    `doi:10.1016/j.physleta.2009.04.045
    <http://dx.doi.org/10.1016/j.physleta.2009.04.045>`__


Visibility graph analysis
=========================
- Introduction: [Lacasa2008]_.
- Application to geophysical time series: [Donner2012]_.
- Tests for time series irreversibility: [Donges2013]_.

....

.. [Lacasa2008] L. Lacasa, B. Luque, F. Ballesteros, J. Luque, J.C. Nuno.
    "From time series to complex networks: The visibility graph".
    In *Proceedings of the National Academy of Sciences of the United States of
    America*, vol. 105 (no. 13), p4972-4975 (2008)
    `doi:10.1073/pnas.0709247105 <http://dx.doi.org/10.1073/pnas.0709247105>`__

.. [Donner2012] R.V. Donner and J.F. Donges.
    "Visibility graph analysis of geophysical time series: Potentials and
    possible pitfalls".
    In *Acta Geophysica*, vol. 60 p589-623 (2012)
    `doi:10.2478/s11600-012-0032-x
    <http://dx.doi.org/10.2478/s11600-012-0032-x>`__

.. [Donges2013] J.F. Donges, R.V. Donner, J. Kurths.
    "Testing time series irreversibility using complex network methods".
    In *Europhysics Letters*, vol. 102.1, 10004 (2013)
    `doi:10.1209/0295-5075/102/10004
    <http://dx.doi.org/10.1209/0295-5075/102/10004>`__
